WriteLockStrategy

Trait WriteLockStrategy 

pub trait WriteLockStrategy<'a>: WriteLockStrategySealed<'a> { }
The write lock strategy supports different lock implementations which can be chosen based on the guarantees required, platform support, and performance constraints.

Note: the lock implementations are sealed to avoid committing to a specific lock interface.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl WriteLockStrategy<'_> for LockDisabled

Source

impl WriteLockStrategy<'_> for SingleWriter

Available on Unix only.